@@ -1,6 +1,7 @@
 /*
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
     SPDX-FileCopyrightText: 2021-2022 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2025 Thomas Duckworth <tduck@filotimoproject.org>
 */
 
 #include "CommandOutputContext.h"
@@ -50,6 +51,9 @@ CommandOutputContext::CommandOutputContext(const QStringList &findExecutables,
         m_foundExecutablePaths[findExecutable] = QStandardPaths::findExecutable(findExecutable);
     }
 
+    m_autoRefreshTimer = new QTimer(this);
+    connect(m_autoRefreshTimer, &QTimer::timeout, this, &CommandOutputContext::refresh);
+
     metaObject()->invokeMethod(this, &CommandOutputContext::load);
 }
 
@@ -97,6 +101,8 @@ void CommandOutputContext::setFilter(const QString &filter)
 
 void CommandOutputContext::reset()
 {
+    setAutoRefresh(false);
+
     m_ready = false;
     m_error.clear();
     m_explanation.clear();
@@ -118,14 +124,21 @@ void CommandOutputContext::load()
 
     for (auto it = m_foundExecutablePaths.cbegin(); it != m_foundExecutablePaths.cend(); ++it) {
         if (it.value().isEmpty()) {
-            setError(xi18nc("@info", "The <command>%1</command> tool is required to display this page, but could not be found", it.key()),
+            setError(xi18nc("@info", "Could not load page content", KOSRelease().name()),
                      xi18nc("@info",
-                            "You can search for it and install it using your package manager.<nl/>"
-                            "Then please report this packaging issue to your distribution."));
+                            "Technical details: The <command>%1</command> tool is required to display this page, but could not be found. You may be able to "
+                            "install it using your package manager; either way, please report this packaging issue to %2.",
+                            it.key(),
+                            KOSRelease().name()));
             return;
         }
     }
 
+    runProcess();
+}
+
+void CommandOutputContext::runProcess()
+{
     auto proc = new QProcess(this);
     proc->setProcessChannelMode(QProcess::MergedChannels);
     connect(proc, &QProcess::finished, this, [this, proc](int /* exitCode */, QProcess::ExitStatus exitStatus) {
@@ -133,8 +146,8 @@ void CommandOutputContext::load()
 
         switch (exitStatus) {
         case QProcess::CrashExit:
-            return setError(xi18nc("@info", "The <command>%1</command> tool crashed while generating page content", m_executableName),
-                            xi18nc("@Info", "Try again later. If keeps happening, please report the crash to your distribution."));
+            return setError(xi18nc("@info", "Could not load page content", KOSRelease().name()),
+                            xi18nc("@Info", "Technical details: the <command>%1</command> tool crashed while generating page content.", m_executableName));
         case QProcess::NormalExit:
             break;
         }
@@ -155,6 +168,53 @@ void CommandOutputContext::load()
     proc->start(m_executablePath, m_arguments);
 }
 
+void CommandOutputContext::refresh()
+{
+    if (!m_ready) {
+        return;
+    }
+
+    metaObject()->invokeMethod(
+        this,
+        [this] {
+            runProcess();
+        },
+        Qt::QueuedConnection);
+}
+
+bool CommandOutputContext::autoRefresh() const
+{
+    return m_autoRefreshTimer->isActive();
+}
+
+void CommandOutputContext::setAutoRefresh(bool autoRefresh)
+{
+    if (m_autoRefreshTimer->isActive() == autoRefresh) {
+        return;
+    }
+
+    if (autoRefresh && m_ready) {
+        m_autoRefreshTimer->start(m_autoRefreshMs);
+    } else {
+        m_autoRefreshTimer->stop();
+    }
+
+    Q_EMIT autoRefreshChanged();
+}
+
+void CommandOutputContext::setAutoRefreshMs(int ms)
+{
+    if (m_autoRefreshMs == ms) {
+        return;
+    }
+
+    m_autoRefreshMs = ms;
+
+    setAutoRefresh(ms > 0 && m_ready);
+
+    Q_EMIT autoRefreshMsChanged();
+}
+
 void CommandOutputContext::setError(const QString &message, const QString &explanation = QString())
 {
     m_error = message;
@@ -172,6 +232,8 @@ void CommandOutputContext::setError(const QString &message, const QString &expla
 void CommandOutputContext::setReady()
 {
     m_ready = true;
+    setAutoRefresh(m_autoRefreshMs > 0);
+
     Q_EMIT readyChanged();
 }
 
